@@ -1,9 +1,10 @@
 import asyncio
 import re
+from time import sleep
 
 import dask
 from dask.distributed import SpecCluster, Worker, Client, Scheduler, Nanny
-from distributed.deploy.spec import close_clusters, ProcessInterface
+from distributed.deploy.spec import close_clusters, ProcessInterface, run_spec
 from distributed.metrics import time
 from distributed.utils_test import loop, cleanup  # noqa: F401
 from distributed.utils import is_valid_xml
@@ -24,7 +25,7 @@ class BrokenWorker(Worker):
 
 
 worker_spec = {
-    0: {"cls": Worker, "options": {"nthreads": 1}},
+    0: {"cls": "dask.distributed.Worker", "options": {"nthreads": 1}},
     1: {"cls": Worker, "options": {"nthreads": 2}},
     "my-worker": {"cls": MyWorker, "options": {"nthreads": 3}},
 }
@@ -131,6 +132,35 @@ async def test_scale(cleanup):
         assert len(cluster.workers) == 2
 
 
+@pytest.mark.slow
+@pytest.mark.asyncio
+async def test_adaptive_killed_worker(cleanup):
+    with dask.config.set({"distributed.deploy.lost-worker-timeout": 0.1}):
+
+        async with SpecCluster(
+            asynchronous=True,
+            worker={"cls": Nanny, "options": {"nthreads": 1}},
+            scheduler={"cls": Scheduler, "options": {"port": 0}},
+        ) as cluster:
+
+            async with Client(cluster, asynchronous=True) as client:
+
+                cluster.adapt(minimum=1, maximum=1)
+
+                # Scale up a cluster with 1 worker.
+                while len(cluster.workers) != 1:
+                    await asyncio.sleep(0.01)
+
+                future = client.submit(sleep, 0.1)
+
+                # Kill the only worker.
+                [worker_id] = cluster.workers
+                await cluster.workers[worker_id].kill()
+
+                # Wait for the worker to re-spawn and finish sleeping.
+                await future.result(timeout=5)
+
+
 @pytest.mark.asyncio
 async def test_unexpected_closed_worker(cleanup):
     worker = {"cls": Worker, "options": {"nthreads": 1}}
@@ -399,8 +429,12 @@ async def test_MultiWorker(cleanup):
             await cluster
             assert len(cluster.worker_spec) == 2
             await client.wait_for_workers(4)
+            while len(cluster.scheduler_info["workers"]) < 4:
+                await asyncio.sleep(0.01)
+
+            while "workers=4" not in repr(cluster):
+                await asyncio.sleep(0.1)
 
-            assert "workers=4" in repr(cluster)
             workers_line = re.search("(Workers.+)", cluster._widget_status()).group(1)
             assert re.match("Workers.*<td>4</td>", workers_line)
 
@@ -428,3 +462,17 @@ async def test_MultiWorker(cleanup):
             future = client.submit(lambda x: x + 1, 10)
             await future
             assert len(cluster.workers) == 1
+
+
+@pytest.mark.asyncio
+async def test_run_spec(cleanup):
+    async with Scheduler(port=0) as s:
+        workers = await run_spec(worker_spec, s.address)
+        async with Client(s.address, asynchronous=True) as c:
+            await c.wait_for_workers(len(worker_spec))
+
+            await asyncio.gather(*[w.close() for w in workers.values()])
+
+            assert not s.workers
+
+            await asyncio.gather(*[w.finished() for w in workers.values()])
